@@ -1,7 +1,6 @@
 // This file is part of retro-gtk. License: GPL-3.0+.
 
-#ifndef __RETRO_GTK_H__
-#define __RETRO_GTK_H__
+#pragma once
 
 #define __RETRO_GTK_INSIDE__
 
@@ -11,6 +10,7 @@
 
 #include "retro-controller.h"
 #include "retro-controller-codes.h"
+#include "retro-controller-iterator.h"
 #include "retro-controller-type.h"
 #include "retro-core.h"
 #include "retro-core-descriptor.h"
@@ -27,8 +27,7 @@
 #include "retro-option-iterator.h"
 #include "retro-pixbuf.h"
 #include "retro-pixdata.h"
+#include "retro-rumble-effect.h"
 #include "retro-video-filter.h"
 
 #undef __RETRO_GTK_INSIDE__
-
-#endif
