@@ -1,7 +1,6 @@
 // This file is part of retro-gtk. License: GPL-3.0+.
 
-#ifndef RETRO_PIXBUF_H
-#define RETRO_PIXBUF_H
+#pragma once
 
 #if !defined(__RETRO_GTK_INSIDE__) && !defined(RETRO_GTK_COMPILATION)
 # error "Only <retro-gtk.h> can be included directly."
@@ -17,5 +16,3 @@ void   retro_pixbuf_set_aspect_ratio (GdkPixbuf *pixbuf,
                                       gfloat     aspect_ratio);
 
 G_END_DECLS
-
-#endif /* RETRO_PIXBUF_H */
